@@ -5,10 +5,38 @@ from sense_push.common import *
 
 class DjangoPushDataHandler(object):
 
-    def __init__(self, model_map):
-        self.model_map = model_map
+    def __init__(self, model_map=None, models=None):
+        if model_map:
+            self.model_map = self._convert_model_map(model_map)
+        else:
+            self.model_map = self._build_model_map(models)
         self.model_field_map = dict()
 
+    def _build_model_map(self, models):
+        result = dict()
+        for model in models:
+            result[model._meta.db_table] = {
+                'model': model,
+                'primary': ['id'],
+            }
+        return result
+
+    def _convert_model_map(self, model_map):
+        result = dict()
+        for k, v in model_map.items():
+            if type(v) != dict:
+                result[k] = {
+                    'model': v,
+                }
+            else:
+                result[k] = v
+            primary = v.get('primary')
+            if not primary:
+                v['primary'] = ['id']
+        if sd.is_debug():
+            sd.log_info("model_map={}".format(result))
+        return result
+
     def get_model_key(self, database, table):
         return "{0}_{1}".format(database, table)
 
